@@ -1,9 +1,9 @@
 # exporting
 from .collectible import Collectible, CollectibleType, MultiCollectible, ShopItem
 from .instruction import Instruction, CXGate, HGate, SwapGate, XGate
-from .pickup import Pickup, Coin, Key, Heart, Energy
+from .pickup import Pickup, Coin, Key, Energy
 from .qubit import Qubit
-from .consumable import Consumable, HealthPotion
+from .consumable import Consumable, EnergyRefill
 from .collectible_factory import CollectibleFactory, GateFactory, OrderedCollectibleFactory, ShopFactory
 
 # importing
